@@ -191,9 +191,13 @@ int bvc_setpeerdisable(BVS_CMD_PARAM *prm)
 	char		prline[128];
 	struct in_addr  sin;
 
-
+	/****
 	clno = (prm->adrs).clno;
 	adrs = (prm->adrs).addr;
+	*****/
+
+	clno = *(int *)prm;
+	adrs = *(u_long *)((char *)prm + sizeof(int));
 	sin.s_addr = adrs;
 
 	pn = check_id1topn(adrs);
@@ -229,8 +233,13 @@ int bvc_setpeerenable(BVS_CMD_PARAM *prm)
 	struct in_addr	sin;
 	struct timeval	timer_value;
 
+	/****
 	clno = (prm->adrs).clno;
 	adrs = (prm->adrs).addr;
+	****/
+
+	clno = *(int *)prm;
+	adrs = *(u_long *)((char *)prm + sizeof(int));
 	sin.s_addr = adrs;
 
 	pn = check_id1topn(adrs);
@@ -350,16 +359,28 @@ int bvc_bgpsum(BVS_CMD_PARAM *prm)
 		adr.s_addr = peer[pn].local_id;
 		strcpy(localident, inet_ntoa(adr));
 		adr.s_addr = peer[pn].neighbor;
-		strcpy(tempstr, ulongtofourbyteas(peer[pn].local_as));
+		sprintf(tempstr, "%lu", (u_long)peer[pn].local_as);
+		/* strcpy(tempstr, ulongtofourbyteas(peer[pn].local_as)); */
 		if (peer[pn].peerstatus == true) {
+			/***
 			sprintf(prline, "%2d %-15s %-11s %-15s %-11s %-12s\r\n",
 				pn, localident, tempstr,
 				inet_ntoa(adr), ulongtofourbyteas(peer[pn].remote_as),
 				fsm_state_names[peer[pn].status]);
+			***/
+			sprintf(prline, "%2d %-15s %-11s %-15s %-11lu %-12s\r\n",
+				pn, localident, tempstr,
+				inet_ntoa(adr), (u_long)(peer[pn].remote_as),
+				fsm_state_names[peer[pn].status]);
 		} else {
+			/***
 			sprintf(prline, "%2d %-15s %-11s %-15s %-11s Admin Down\r\n",
 				pn, localident, tempstr,
 				inet_ntoa(adr), ulongtofourbyteas(peer[pn].remote_as));
+			***/
+			sprintf(prline, "%2d %-15s %-11s %-15s %-11lu Admin Down\r\n",
+				pn, localident, tempstr,
+				inet_ntoa(adr), (u_long)(peer[pn].remote_as));
 		}
 		bvs_write(clno, prline);
 	}
@@ -373,8 +394,14 @@ int bvs_clearbgp(BVS_CMD_PARAM *prm)
 	char		prline[128];
 	int		pn;
 
+	/****
 	clno = (prm->adrs).clno;
 	sin.s_addr = (prm->adrs).addr;
+	****/
+
+	clno = *(int *)prm;
+	sin.s_addr = *(u_long *)((char *)prm + sizeof(int));
+
 	sprintf(prline, "Reset Peer : %s\r\n", inet_ntoa(sin));
 	bvs_write(clno, prline);
 	pn = check_id1topn(sin.s_addr);
@@ -404,7 +431,8 @@ int bvc_shousers(BVS_CMD_PARAM *prm)
 	cnt = 0;
 	bvs_write(clno, "  No Address         LoginTime\r\n");
 	while(cnt < (bvs_maxcon-1)) {
-		if ((bvs_clients + cnt)->clsock != (int)NULL) {
+		/* if ((bvs_clients + cnt)->clsock != (int)NULL) { */
+		if ((bvs_clients + cnt)->clsock != 0) {
 			sin.s_addr = htonl((bvs_clients + cnt)->addr);
 			gettimeofday(&nowtime, (struct timezone *)0);
 			btmin = (nowtime.tv_sec -
@@ -432,9 +460,19 @@ int bvc_shoneighbor(BVS_CMD_PARAM *prm)
 
 	char		*BOOL[] = { "OFF", "ON" };
 
+	/****
 	clno = (prm->adrs).clno;
 	sin.s_addr = (prm->adrs).addr;
+	****/
+
+	clno = *(int *)prm;
+	sin.s_addr = *(u_long *)((char *)prm + sizeof(int));
+
 	pn = check_id1topn(sin.s_addr);
+
+#ifdef DEBUG
+	printf("DEBUG: SEARCH PEER(bvc_shoneighbor): %08X\n", ntohl(sin.s_addr));
+#endif
 	if (pn < 0) {
 		bvs_write(clno, "Not found peer\r\n");
 	} else {
@@ -445,15 +483,23 @@ int bvc_shoneighbor(BVS_CMD_PARAM *prm)
 		sprintf(prline, "    Neighbor Address : %s\r\n",
 					inet_ntoa(sin));
 		bvs_write(clno, prline);
+		/***
 		sprintf(prline, "    Remote AS        : %s\r\n",
 					ulongtofourbyteas(peer[pn].remote_as));
+		***/
+		sprintf(prline, "    Remote AS        : %lu\r\n",
+					(u_long)(peer[pn].remote_as));
 		bvs_write(clno, prline);
 		sin.s_addr = peer[pn].local_id;
 		sprintf(prline, "    Individual IDENT : %s\r\n",
 					inet_ntoa(sin));
 		bvs_write(clno, prline);
+		/***
 		sprintf(prline, "    Individual AS    : %s\r\n",
 					ulongtofourbyteas(peer[pn].local_as));
+		***/
+		sprintf(prline, "    Individual AS    : %lu\r\n",
+					(u_long)(peer[pn].local_as));
 		bvs_write(clno, prline);
 		if (peer[pn].peerstatus == false) {
 			bvs_write(clno, 
@@ -602,8 +648,14 @@ int bvc_shostatics(BVS_CMD_PARAM *prm)
 	struct timeval	now;
 	long		dift;
 
+	/***
 	clno = (prm->adrs).clno;
 	sin.s_addr = (prm->adrs).addr;
+	***/
+
+	clno = *(int *)prm;
+	sin.s_addr = *(u_long *)((char *)prm + sizeof(int));
+
 	pn = check_id1topn(sin.s_addr);
 	if (pn < 0) {
 		bvs_write(clno, "Not found peer\r\n");
@@ -669,8 +721,14 @@ int bvc_clrstatics(BVS_CMD_PARAM *prm)
 	char		prline[128];
 	int		pn;
 
+	/***
 	clno = (prm->adrs).clno;
 	sin.s_addr = (prm->adrs).addr;
+	****/
+
+	clno = *(int *)prm;
+	sin.s_addr = *(u_long *)((char *)prm + sizeof(int));
+
 	pn = check_id1topn(sin.s_addr);
 	if (pn < 0) {
 		bvs_write(clno, "Not found peer\r\n");
@@ -726,8 +784,12 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 	sin.s_addr = IDENT;
 	sprintf(prline, "  Local BGP Identifier    : %s\r\n", inet_ntoa(sin));
 	bvs_write(clno, prline);
+	/***
 	sprintf(prline, "  Local AS Number         : %d\r\n", 
 						ulongtofourbyteas(LOCAL_AS));
+	***/
+	sprintf(prline, "  Local AS Number         : %lu\r\n", 
+						(u_long)(LOCAL_AS));
 	bvs_write(clno, prline);
 	sprintf(prline, "  Sendmail Command        : %s\r\n", sendmail_command);
 	bvs_write(clno, prline);
@@ -922,11 +984,13 @@ int bvc_doroutertt(BVS_CMD_PARAM *prm)
 	int		timeout;
 	int		ret;
 
+	/**** My be bugged **** from here 
 	clno 	  = (prm->routertt).clno;
 	neighbor  = (prm->routertt).neighbor;
 	prefix    = (prm->routertt).prefix;
 	prefixlen = (prm->routertt).prefixlen;
 	timeout   = (prm->routertt).timeout;
+	**** to here ***/
 
 	ret = newcheckrtt(clno, neighbor, prefix, prefixlen, timeout);
 	switch(ret) {
@@ -1552,8 +1616,17 @@ int bvc_show_bgproute_neighbor(BVS_CMD_PARAM *prm)
 		return(0);
 	}
 
+	/*****
 	clno = (prm->adrs).clno;
 	neigh = (prm->adrs).addr;
+	*****/
+
+	clno = *(int *)prm;
+	neigh = *(net_ulong *)((char *)prm + sizeof(int));
+
+#ifdef DEBUG
+	printf("DEBUG: SEARCH Neigh(bvc_show_bgproute_neighbor): %08X\n", ntohl(neigh));
+#endif
 
 	if (*(cnode+clno) == NULL) {
 		bvs_write(clno, "\r\n ! : Inactive Route\r\n\r\n");
@@ -1611,8 +1684,35 @@ int bvc_showipbgproute(BVS_CMD_PARAM *prm)
 	net_ulong	prefix;
 	RADIX_T		*node;
 
+	/***
 	clno = (prm->adrs).clno;
-	prefix = (prm->adrs).addr;
+	prefix = (net_ulong)(prm->adrs).addr;
+	***/
+
+	clno = *(int *)prm;
+	prefix = *(net_ulong *)((char *)prm + sizeof(int));
+
+#ifdef DEBUG
+	printf("DEBUG: SEARCH ROUTE: %08X\n", ntohl(prefix));
+	printf("DEBIG: prm print: %i / %08X\n", *(int *)prm, *(u_long *)(prm + sizeof(int)));
+	printf("DEBUG: Param DUMP: %02X%02X%02X%02X %02X%02X%02X%02X %02X%02X%02X%02X %02X%02X%02X%02X\n",
+		*((char *)prm),
+		*((char *)prm+1),
+		*((char *)prm+2),
+		*((char *)prm+3),
+		*((char *)prm+4),
+		*((char *)prm+5),
+		*((char *)prm+6),
+		*((char *)prm+7),
+		*((char *)prm+8),
+		*((char *)prm+9),
+		*((char *)prm+10),
+		*((char *)prm+11),
+		*((char *)prm+12),
+		*((char *)prm+13),
+		*((char *)prm+14),
+		*((char *)prm+15) );
+#endif
 
 	bvs_write(clno, "\r\n ! : Inactive Route\r\n\r\n");
 	bvs_write(clno, 
@@ -2395,8 +2495,13 @@ int bvc_show_bgpnexthop_sum_neighbor(BVS_CMD_PARAM *prm)
 		return(0);
 	}
 
+	/****
 	clno = (prm->adrs).clno;
 	neigh = (prm->adrs).addr;
+	****/
+
+	clno = *(int *)prm;
+	neigh = *(net_ulong *)((char *)prm + sizeof(int));
 
 	if (*(cnode+clno) == NULL) {
 		bvs_write(clno, "BGP Next Hop Summarizing ...");
@@ -3165,8 +3270,14 @@ int bvc_doclearpeerroute(BVS_CMD_PARAM *prm)
 	char		prline[128];
 	int		pn;
 
+	/****
 	clno = (prm->adrs).clno;
 	nei = (prm->adrs).addr;
+	****/
+
+	clno = *(int *)prm;
+	nei = *(net_ulong *)((char *)prm + sizeof(int));
+
 	pn = check_id1topn(nei);
 
 	sprintf(prline, "Clearing Peer Route: Peer No = %d\r\n", pn);
