@@ -72,7 +72,8 @@ int bvs_cmd_exit(BVS_CMD_PARAM *prm)
 
 	clno = (prm->noparam).clno;
 	close((bvs_clients+clno)->clsock);
-	(bvs_clients+clno)->clsock = (int)NULL;
+	/* (bvs_clients+clno)->clsock = (int)NULL; */
+	(bvs_clients+clno)->clsock = 0;
 }
 
 void bvs_entry_command(int (*function)(BVS_CMD_PARAM *), 
@@ -662,7 +663,8 @@ int bvs_init_start()
 #ifdef DEBUG
 	printf("DEBUG: BVS Inline VTY1 Open -");
 #endif
-	if (((bvs_clients+bvs_maxcon-1)->clsock = open("/dev/null", O_WRONLY)) == (int)NULL){
+	/* if (((bvs_clients+bvs_maxcon-1)->clsock = open("/dev/null", O_WRONLY)) == (int)NULL){ */
+	if (((bvs_clients+bvs_maxcon-1)->clsock = open("/dev/null", O_WRONLY)) == 0){
 		printf("Inline Virtual Terminal Could not open..\n");
 		return(1); 
 	}
@@ -681,7 +683,8 @@ void bvs_finish(int type)
 	cnt = 0;
 	while(cnt < bvs_maxcon) {
 		if (bvs_clients == NULL) break;
-		if ((bvs_clients + cnt)->clsock != (int)NULL) {
+		/* if ((bvs_clients + cnt)->clsock != (int)NULL) { */
+		if ((bvs_clients + cnt)->clsock != 0) {
 			if (type != PROC_CHILDEND) {
 			  bvs_write(cnt, "BVS Close Request Received...\r\n");
 			}
@@ -704,7 +707,8 @@ void bvs_readsocset(fd_set *fds)
 	FD_SET(bvs_svsoc, fds);
 	cnt = 0;
 	while(cnt < bvs_maxcon-1) {
-		if ((bvs_clients + cnt)->clsock != (int)NULL) {
+		/* if ((bvs_clients + cnt)->clsock != (int)NULL) { */
+		if ((bvs_clients + cnt)->clsock != 0) {
 			FD_SET((bvs_clients + cnt)->clsock, fds);
 		}
 		cnt++;
@@ -773,6 +777,9 @@ void *bvs_search_function(const char *cmdline, BVS_CMD_PARAM *param, boolean *mo
 				if (strcmp((curptr->word)+1,"ADR")==0) {
 				    inet_aton(words[lv], &sin);
 				    *(u_long *)prmptr = sin.s_addr;
+#ifdef DEBUG
+				    printf("DEBUG: BVS: Address Parameter = %08X\n", ntohl(*(u_long *)prmptr));
+#endif
 				    prmptr += sizeof(u_long);
 				} else if (strcmp((curptr->word)+1,"INT")==0) {
 				    *(int *)prmptr = atoi(words[lv]);
@@ -1067,7 +1074,8 @@ int bvs_write(int clno, char *str)
 	ptr = str;
 	left = length;
 	rtcnt = 0;
-	if ((bvs_clients+clno)->clsock == (int)NULL) {
+	/* if ((bvs_clients+clno)->clsock == (int)NULL) { */
+	if ((bvs_clients+clno)->clsock == 0) {
 		return(-1);
 	}
 	while(left > 0) {
@@ -1089,7 +1097,8 @@ int bvs_write(int clno, char *str)
 				sprintf(logstr, "BVS: Write Error : %d\n", errno);
 				pr_log(VLOG_GLOB, LOG_ALL, logstr, ON);
 				close((bvs_clients+clno)->clsock);
-				(bvs_clients+clno)->clsock = (int)NULL;
+				/* (bvs_clients+clno)->clsock = (int)NULL; */
+				(bvs_clients+clno)->clsock = 0;
 				return written;
 			}
 			left -= written;
@@ -1689,7 +1698,8 @@ int bvs_input(fd_set *fds)
 	
 	cnt = 0;
 	while(cnt < (bvs_maxcon-1)) {
-		if ((bvs_clients+cnt)->clsock == (int)NULL) {
+		/* if ((bvs_clients+cnt)->clsock == (int)NULL) { */
+		if ((bvs_clients+cnt)->clsock == 0) {
 			cnt++;
 			continue;
 		}
@@ -1707,7 +1717,8 @@ int bvs_input(fd_set *fds)
 						&instr, MAXIMUM_CMD_LENGTH);
 			if (readc == 0) {
 				close((bvs_clients+cnt)->clsock);
-				(bvs_clients+cnt)->clsock = (int)NULL;
+				/* (bvs_clients+cnt)->clsock = (int)NULL; */
+				(bvs_clients+cnt)->clsock = 0;
 				cnt++;
 				continue;
 			}
@@ -1735,7 +1746,8 @@ int bvs_input(fd_set *fds)
 			fflush(stdout);
 #endif
 			bzero(tgstr, MAXIMUM_CMD_LENGTH+1);
-			while(instr[cpnt] != (int)NULL) {
+			/* while(instr[cpnt] != (int)NULL) { */
+			while(instr[cpnt] != 0) {
 #ifdef DEBUG
 				printf("%02X", instr[cpnt]);
 				fflush(stdout);
@@ -2012,7 +2024,8 @@ int bvs_open_new_shell(fd_set *fds)
 		/* Initialize New Client */
 		cnt = 0;
 		while(cnt < (bvs_maxcon-1)) {
-			if ((bvs_clients+cnt)->clsock == (int)NULL) break;
+			/* if ((bvs_clients+cnt)->clsock == (int)NULL) break;*/
+			if ((bvs_clients+cnt)->clsock == 0) break;
 			cnt++;
 		}
 		if (cnt < (bvs_maxcon-1)) {
