@@ -107,7 +107,8 @@ int set_bgp_update_prev()
 		cnt = 0;
 		asptr = strtok(path, "_");
 		while(asptr != NULL) {
-			aspathdiv[cnt] = fourbyteastoulong(asptr);
+			sscanf(asptr, "%lu", &aspathdiv[cnt]); 
+			/* aspathdiv[cnt] = fourbyteastoulong(asptr); */
 			/* sscanf(asptr, "%hu", &aspathdiv[cnt]); */
 			cnt++;
 			asptr = strtok(NULL, "_");
