@@ -213,10 +213,12 @@ int add_route(ROUTE_INFO *rinfo)
 		}
 #ifdef RADIXDEBUG
 		printf("DEBUG: RADIX: Add Route / Node Check Parm\n");
-		printf("DEBUG: RADIX:  rinfo->length = %d / c_leaf->check_bit = %d\n",
-						rinfo->length, c_leaf->check_bit);
+		printf("DEBUG: RADIX:  rinfo->length = %d / c_leaf->check_bit = %d / key = %08X\n",
+			rinfo->length, c_leaf->check_bit, ntohl(c_leaf->key));
 		printf("DEBUG: RADIX:  cbit = %d / scbit = %d / loopbit = %d\n",
 							cbit, scbit, loopbit);
+		printf("DEBUG: RADIX: Entry Route : %08X/%d (add_route)\n",
+			ntohl(rinfo->prefix), rinfo->length);
 #endif
 		
 		if (!(cbit <= loopbit) || (loopbit != c_leaf->check_bit)) { 
@@ -237,9 +239,17 @@ int add_route(ROUTE_INFO *rinfo)
 			}
 			ladd->upleaf = c_leaf->upleaf;
 			ladd->check_bit = loopbit;
+			ladd->key = 
+			  htonl((net_ulong)(((long)0xFFFFFFFF << (31-loopbit)) &
+							 ntohl(rinfo->prefix)));
+/**
 			ladd->key = 
 				htonl((net_ulong)(((long)0x80000000 >> loopbit) &
 							 ntohl(rinfo->prefix)));
+**/
+#ifdef DEBUG
+printf("DEBUG: %08X\n", (long)0xFFFFFFFF << (31-loopbit));
+#endif
 			nodes++;
 			if (c_leaf->upleaf != NULL) {
 				if (c_leaf == (c_leaf->upleaf)->r_leaf) {
@@ -250,6 +260,13 @@ int add_route(ROUTE_INFO *rinfo)
 			}
 			c_leaf->upleaf = ladd;
 			c_leaf = ladd;
+#ifdef RADIXDEBUG2
+		printf("DEBUG: RADIX: Added Node Infomation\n");
+		printf("DEBUG: RADIX:  rinfo->length = %d / c_leaf->check_bit = %d / key = %08X\n",
+			rinfo->length, c_leaf->check_bit, ntohl(c_leaf->key));
+		printf("DEBUG: RADIX:  cbit = %d / scbit = %d / loopbit = %d\n",
+							cbit, scbit, loopbit);
+#endif
 		}
 
 		if ((rinfo->prefix == c_leaf->key) &&
@@ -298,6 +315,13 @@ int add_route(ROUTE_INFO *rinfo)
 				c_leaf = c_leaf->l_leaf;
 			}
 		}
+#ifdef RADIXDEBUG2
+		printf("DEBUG: RADIX: Next Node Infomation\n");
+		printf("DEBUG: RADIX:  rinfo->length = %d / c_leaf->check_bit = %d\n",
+						rinfo->length, c_leaf->check_bit);
+		printf("DEBUG: RADIX:  cbit = %d / scbit = %d / loopbit = %d\n",
+							cbit, scbit, loopbit);
+#endif
 	}
 	switch(ret) {
 		case 1: /* Add New Route */
@@ -826,13 +850,23 @@ RADIX_T *search_route(net_ulong prefix, int masklen)
 	rcode = 0;
 	while(1) {
 		if (node->masklen != 0) {
+			cmask = ((long)0xFFFFFFFF << (31-node->masklen) &
+				 (long)0xFFFFFFFF << (32-masklen));
+			/***
 			cmask = ((long)0x80000000 >> (node->masklen)) & 
 				       ((long)0x80000000 >> (masklen-1));
+			****/
 #ifdef DEBUG
+			/****
 			printf("DEBUG: RADIX: SEARCH: Check MASK p1 = %08X\n",
 					((long)0x80000000 >> (node->masklen)));
 			printf("DEBUG: RADIX: SEARCH: Check MASK p2 = %08X\n",
 					((long)0x80000000 >> (masklen-1)));
+			****/
+			printf("DEBUG: RADIX: SEARCH: Check MASK p1 = %08X\n",
+					((long)0xFFFFFFFF << (31-node->masklen)));
+			printf("DEBUG: RADIX: SEARCH: Check MASK p2 = %08X\n",
+					((long)0xFFFFFFFF << (32-masklen)));
 			printf("DEBUG: RADIX: SEARCH: Check MASK to = %08X\n", cmask);
 #endif
 			if ((ntohl(prefix) & cmask) == ntohl(node->key)) break;
