@@ -496,6 +496,9 @@ void pr_update(int pn)
 					strcat(logstr, cbuf);
 				  }
 				  pr_log(VLOG_UPAT, pn, logstr, OFF);
+#ifdef DEBUG
+				  printf("LOGSTR:%s\n", logstr);
+#endif
 				  length = *(unsigned char *)(ptr+ptmp);
 				  ptmp++;
 				  sprintf(logstr, "%d\n", length);
@@ -505,20 +508,43 @@ void pr_update(int pn)
 				    case AS_CONFED_SEQUENCE:
 					strcat(pathbuf, "(");
 					break;
+				    case AS_SET:
+					strcat(pathbuf, "{");
+					break;
 				  }
 				  cp = ptr + ptmp;
 				  if (peer[pn].as4_remote && peer[pn].as4_enable) {
 				    for(cnt = 0; cnt < length; cnt++, cp += 4){
+				      /***
 				      strcpy(cbuf, 
 					ulongtofourbyteas(buf2ulong(cp)));
-				      strcat(cbuf, " ");
-				      strcat(pathbuf, cbuf);
+				      **/
+				      sprintf(cbuf, "%lu", (u_long)buf2ulong(cp));
+				      switch(getroute.path_type) {
+					case AS_SET:
+				          strcat(cbuf, ",");
+				          strcat(pathbuf, cbuf);
+					  break;
+					default:
+				          strcat(cbuf, " ");
+				          strcat(pathbuf, cbuf);
+					  break;
+				      }
 				    }
 				  } else {
 				    for(cnt = 0; cnt < length; cnt++, cp += 2){
-					sprintf(cbuf, "%d ",
+				      switch(getroute.path_type) {
+					case AS_SET:
+					  sprintf(cbuf, "%d,",
 						(int)buf2ushort(cp));
-					strcat(pathbuf, cbuf);
+					  strcat(pathbuf, cbuf);
+					  break;
+					default:
+					  sprintf(cbuf, "%d ",
+						(int)buf2ushort(cp));
+					  strcat(pathbuf, cbuf);
+					  break;
+				      }
 				    }
 				  }
 				  switch(getroute.path_type) {
@@ -530,6 +556,13 @@ void pr_update(int pn)
 					}
 					strcat(pathbuf, ") ");
 					break;
+				    case AS_SET:
+					cnt = strlen(pathbuf);
+					if (cnt > 0) {
+					  pathbuf[cnt-1] = '\0';
+					}
+					strcat(pathbuf, "} ");
+					break;
 				  }
 				  if (peer[pn].as4_remote && peer[pn].as4_enable) {
 				    ptmp += length*4;
@@ -550,6 +583,11 @@ void pr_update(int pn)
 					strcpy(v6getroute.pathset_ptr, pathbuf);
 					sprintf(logstr, "    AS_Path = %s\n",
 								getroute.pathset_ptr);
+#ifdef DEBUG
+					printf(logstr, "    AS_Path = %s\n",
+								getroute.pathset_ptr);
+#endif
+					
 				}
 				pr_log(VLOG_UPAT, pn, logstr, OFF);
 				ptr += attr_octs;
@@ -742,6 +780,9 @@ void pr_update(int pn)
 					strcat(logstr, cbuf);
 				  }
 				  pr_log(VLOG_UPAT, pn, logstr, OFF);
+#ifdef DEBUG
+				  printf("LOGSTR:%s\n", logstr);
+#endif
 				  length = *(unsigned char *)(ptr+ptmp);
 				  ptmp++;
 				  sprintf(logstr, "%d\n", length);
@@ -751,13 +792,29 @@ void pr_update(int pn)
 				    case AS_CONFED_SEQUENCE:
 					strcat(as4_pathbuf, "(");
 					break;
+				    case AS_SET:
+					strcat(as4_pathbuf, "{");
+					break;
 				  }
 				  cp = ptr + ptmp;
 				  for(cnt = 0; cnt < length; cnt++, cp += 4){
+				    switch(as4_getroute.path_type) {
+				      case AS_SET:
+					sprintf(cbuf, "%lu,", 
+						(u_long)buf2ulong(cp));
+					strcat(as4_pathbuf, cbuf);
+					break;
+				      default:
+					/***
 					sprintf(cbuf, "%d.%d ",
 						(int)buf2ushort(cp),
 						(int)buf2ushort(cp+2));
+					****/
+					sprintf(cbuf, "%lu,", 
+						(u_long)buf2ulong(cp));
 					strcat(as4_pathbuf, cbuf);
+					break;
+				    }
 				  }
 				  switch(as4_getroute.path_type) {
 				    case AS_CONFED_SET:
@@ -768,6 +825,13 @@ void pr_update(int pn)
 					}
 					strcat(as4_pathbuf, ") ");
 					break;
+				    case AS_SET:
+					cnt = strlen(as4_pathbuf);
+					if (cnt > 0) {
+					  as4_pathbuf[cnt-1] = '\0';
+					}
+					strcat(as4_pathbuf, "} ");
+					break;
 				  }
 				  ptmp += length*4;
 				}
@@ -853,6 +917,9 @@ void pr_update(int pn)
 		pt2 += cnt+1;
 
 		write_prefixlog(0, &prroute, pn);
+#ifdef DEBUG
+		printf("DEBUG: Entering add_route\n");
+#endif
 
 #ifdef RADIX
 		/* Add Route to RADIX Tree */
